pub fn dump_strings<T: Activated>(
cap: &mut Capture<T>,
len: &usize,
resolver: &mut Option<Box<Resolver>>,
block_print: &bool,
regex: &Option<Regex>,
)Expand description
Dump any valid ASCII strings over len size to stdout.
If resolver is passed in, this function will use it to perform DNS
lookups on addresses.
If block_print is set, the function will only print the packet headers
for the first ASCII line found.
If regex is provided this is run against the entire packet before
the string scanning is run. Packets not matching the regex are skipped.